ZipArchiveExt extension
A utility extension that get document entry directly from a ZipArchive.
It would be invalid docx file if its entries do not contain
word/document.xml.
- on
-
- ZipArchive
Properties
- doc → ZipFileEntry
-
Available on ZipArchive, provided by the ZipArchiveExt extension
no setter