A standalone class that convert a RandomAccessFile file to a xml stream,
which is the main content of the given docx file.
A zip file is totally designed for RandomAccessFile, so it could not be
implemented as a stream transformer.
A transformer class that could convert a text stream into a docx stream.
It receive a raw text stream, splitting lines innerly and assembling xml
nodes as text, then encode them into binary stream.
This binary stream is used to construct a zip archive, and at this time
generate zip stream with zip from zip2.